@@ -1,6 +1,6 @@
 use utf8;
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.153350';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.153360';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
@@ -64,6 +64,8 @@ sub new{
 	my $self = bless { 
 			next_id => 1,
 			bindings => '',
+			before_bindings => '',
+			after_bindings => '',
 		}, $class;
 	return $self;
 }
@@ -245,7 +247,14 @@ sub dxbuild {
 	my $c = shift;
 	my $dxhelper = $c->stash('dxHelper') or return;
 	if($dxhelper->{bindings}){
-		out '<script language="javascript">$(window).on("load",function(){'."\n".$dxhelper->{bindings}."\n".'});</script>';
+		out '<script language="javascript">$(window).on("load",function(){'.
+			"\n".
+			join("\n",
+				 grep{ ($_//'') ne ''}
+				 @$dxhelper{'before_bindings','bindings','after_bindings'}
+			).
+			"\n".
+			'});</script>';
 	}
 }
 
@@ -274,8 +283,27 @@ sub required_assets{
 	return $results;
 }
 
+sub prepend_js{
+	my ($c, @js) = @_;
+	my $dxhelper = $c->stash('dxHelper') or return;
+	for(@js){
+		$dxhelper->{before_bindings} .= "\n" if $INDENT_BINDING;
+		$dxhelper->{before_bindings} .= $_;
+	}
+}
+
+
+sub append_js{
+	my ($c, @js) = @_;
+	my $dxhelper = $c->stash('dxHelper') or return;
+	for(@js){
+		$dxhelper->{after_bindings} .= "\n" if $INDENT_BINDING;
+		$dxhelper->{after_bindings} .= $_;
+	}
+}
+
 #Helper method to export without prepending a prefix
-my @without_prefix = qw( dxbuild required_assets require_asset indent_binding );
+my @without_prefix = qw( dxbuild required_assets require_asset indent_binding append_js prepend_js );
 
 #Helper method to export with prepending a prefix
 my @with_prefix = (qw( Button DataGrid Popup Menu LoadPanel Lookup ),
@@ -328,7 +356,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.153350
+version 0.153360
 
 =head1 SUBROUTINES/METHODS
 
@@ -477,6 +505,18 @@ in your layout:
 Add assets that was specified by calls to require_asset.
 See require_asset for usage.
 
+=head2 prepend_js
+
+Prepend javascript code to dx-generated code
+
+	append_js 'alert("before dx-controls initialisation");'
+
+=head2 append_js 
+
+Append javascript code to dx-generated code
+
+	append_js 'alert("after dx-controls initialisation");'
+
 =head2 register
 
 Register our helpers
